OnnxRuntime class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createSession(
String modelPath, {OrtSessionOptions? options}) → Future< OrtSession> - Create an ONNX Runtime session with the given model path
-
createSessionFromAsset(
String assetKey, {OrtSessionOptions? options}) → Future< OrtSession> - Create an ONNX Runtime session from an asset model file
-
getAvailableProviders(
) → Future< List< OrtProvider> > - Get the available providers
-
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited