OrtModelMetadata class

Constructors

OrtModelMetadata({required String producerName, required String graphName, required String domain, required String description, required int version, required Map<String, String> customMetadataMap})
OrtModelMetadata.fromMap(Map<String, dynamic> map)
factory

Properties

customMetadataMap Map<String, String>
final
description String
final
domain String
final
graphName String
final
hashCode int
The hash code for this object.
no setterinherited
producerName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts the metadata to a Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited