OrtSessionOptions class

Constructors

OrtSessionOptions({int? intraOpNumThreads, int? interOpNumThreads, List<OrtProvider>? providers, bool? useArena, int? deviceId})

Properties

deviceId int?
final
hashCode int
The hash code for this object.
no setterinherited
interOpNumThreads int?
final
intraOpNumThreads int?
final
providers List<OrtProvider>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useArena bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited